@@ -31,6 +31,13 @@ public:
 private Q_SLOTS:
     void shouldHaveDefaultValue();
     void shouldBeAbleToImportSettings();
+    void shouldHaveDefaultValueWithEmptyDirectory();
+    void shouldBeAbleToImportSettings2();
+
+    void shouldHaveImportSettings();
+    void shouldHaveImportSettings_data();
+    void shouldImportSieveSettings_data();
+    void shouldImportSieveSettings();
 };
 
 #endif // IMPORTIMAPSETTINGSTHUNDERBIRDCHECKJOBTEST_H
