@@ -84,7 +84,9 @@ void ImportImapSettingProgressPage::start()
 
 void ImportImapSettingProgressPage::slotImportSettingsDone(const QString &name, const SieveEditorUtil::SieveServerConfig &settings)
 {
-    addProgressInfo(i18n("Import settings %1", name));
+    const QString str{i18n("Import settings %1", name)};
+    addProgressInfo(str);
+    Q_EMIT addSummaryInfo(str);
     SieveEditorUtil::addServerSieveConfig(settings);
     mSettingsFound = true;
 }
